@@ -55,6 +55,9 @@ main_xdg_autostart="/etc/xdg/autostart";
 rox_path="/usr/bin/rox-filer"
 space_path="/usr/bin/spacefm"
 zzz_path="/usr/bin/zzzfm"
+icewm_path="/usr/bin/icewm"
+jwm_path="/usr/bin/jwm"
+fluxbox_path="/usr/bin/fluxbox"
 
 #Xsessions
 xs_dir="/usr/share/xsessions";
